pygeodesy.errors.LimitError

Package pygeodesy :: Module errors :: Class LimitError |
[frames] | no frames]

# Class LimitError

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
            exceptions.StandardError --+
                                       |
                   exceptions.ValueError --+
                                           |
                                 _ValueError --+
                                               |
                                              LimitError

Known Subclasses:
  - UnitError

Error raised for lat- or longitudinal values or deltas exceeding the given `limit` in functions equirectangular, equirectangular4, `nearestOn*` and `simplify*` or methods with `limit` or `options` keyword arguments.

See Also: Subclass UnitError.

Instance Methods
Inherited from `_ValueError`: `__init__` Inherited from `exceptions.ValueError`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`